# -------------------------------------------------------------------------------- NOTEBOOK-CELL: CODE
# -*- coding: utf-8 -*-
import dataiku
import pandas as pd, numpy as np
from dataiku import pandasutils as pdu
from eod_historical_data import EODHistoricalData
import concurrent.futures
import os

# -------------------------------------------------------------------------------- NOTEBOOK-CELL: CODE
# Read recipe inputs
sp500_tickers = dataiku.Dataset("tickers_list")
sp500_tickers_df = sp500_tickers.get_dataframe()

symbols = sp500_tickers_df.ticker

client = dataiku.api_client()
auth_info = client.get_auth_info(with_secrets=True)

secret_value = None
for secret in auth_info["secrets"]:
    if secret["key"] == "EOD_api_token":
        secret_value = secret["value"]
        break

if not secret_value:
    raise Exception("API key not found in user secrets")

data_source = dataiku.get_custom_variables()['data_source']
if data_source=='eodhistoricaldata':
    retriever = EODHistoricalData(secret_value, 1)
else:
    raise Exception('data source not accepted')

benzinga_news = dataiku.Folder("UuYyQIUF")
path = benzinga_news.get_path()

# -------------------------------------------------------------------------------- NOTEBOOK-CELL: CODE
def download_data(symbol):
    print(symbol)
    data = retriever.get_news_data(symbol)
    file_path = os.path.join(path, data_source + '_' + symbol + '.csv')
    data.to_csv(file_path)

# -------------------------------------------------------------------------------- NOTEBOOK-CELL: CODE
threads = min(30, len(symbols))

with concurrent.futures.ThreadPoolExecutor(max_workers=threads) as executor:
    executor.map(download_data, symbols)